#
# spec file for package openrct2
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define lib_suffix %{nil}
%ifarch x86_64
  %define lib_suffix 64
%endif
%define title_version 0.4.0
%define title_version_url %{title_version}
%define objects_version 1.3.11
%define openmusic_version 1.3.0
%define opensound_version 1.0.3
%define openrct2_version 0.4.5

Name:           openrct2
Version:        %{openrct2_version}
Release:        4.1
Summary:        An open source re-implementation of Roller Coaster Tycoon 2
License:        GPL-3.0-only
Group:          Amusements/Games/Strategy/Other
URL:            https://openrct2.io/
Source0:        https://github.com/OpenRCT2/OpenRCT2/archive/v%{version}/OpenRCT2-%{version}.tar.gz
Source1:        https://github.com/OpenRCT2/title-sequences/archive/v%{title_version_url}/title-sequences-%{title_version_url}.tar.gz
Source2:        https://github.com/OpenRCT2/objects/archive/v%{objects_version}.tar.gz#/objects-%{objects_version}.tar.gz
Source3:        https://github.com/OpenRCT2/Openmusic/releases/download/v%{openmusic_version}/openmusic.zip#/openmusic-%{openmusic_version}.zip
Source4:        https://github.com/OpenRCT2/OpenSoundEffects/releases/download/v%{opensound_version}/opensound.zip#/opensound-%{opensound_version}.zip
#PATCH-FIX-UPSTREAM Included in next release: https://github.com/OpenRCT2/OpenRCT2/pull/19519
Source5:        https://raw.githubusercontent.com/OpenRCT2/OpenMusic/master/COPYING
BuildRequires:  cmake >= 3.9
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  glibc-devel
BuildRequires:  hicolor-icon-theme
BuildRequires:  nlohmann_json-devel >= 3.6.0
BuildRequires:  pkgconfig
BuildRequires:  shared-mime-info
BuildRequires:  update-desktop-files
BuildRequires:  zip
BuildRequires:  pkgconfig(duktape)
BuildRequires:  pkgconfig(flac)
BuildRequires:  pkgconfig(fontconfig)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(icu-uc) >= 59.0
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(libpng16)
BuildRequires:  pkgconfig(libzip) >= 1.0
BuildRequires:  pkgconfig(openssl) >= 1.0.0
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(speexdsp)
BuildRequires:  pkgconfig(vorbisfile)
BuildRequires:  pkgconfig(zlib)
Recommends:     %{name}-openmusic
Recommends:     %{name}-opensound
Recommends:     %{name}-titlesequences
Recommends:     (kdialog or zenity)
ExcludeArch:    s390x

%description
An open source clone of RollerCoaster Tycoon 2
that depends on the original game assets. On first
game start it will create a ~/.config/OpenRCT2/config.ini file
where the game_path = "" setting has to be set to a directory
into which the original game has been installed to.

%package titlesequences
Version:        %{title_version}
Summary:        Titlesequences for openRCT2
License:        CC-BY-4.0
Group:          Amusements/Games/Strategy/Other
Requires:       openrct2 = %{openrct2_version}
BuildArch:      noarch

%description titlesequences
This package contains tilesequences like the original ones
used in RollerCoaster Tycoon 1 and 2.
When using RCT1 sequences, the original RCT1 files have to be installed.

%package openmusic
Version:        %{openmusic_version}
Summary:        Open soundtracks for openRCT2
License:        CC-BY-4.0
Group:          Amusements/Games/Strategy/Other
Requires:       openrct2 = %{openrct2_version}
BuildArch:      noarch

%description openmusic
High quality soundtrack as replacement for, and addition to RollerCoaster Tycoon 2's
soundtrack.

%package opensound
Version:        %{opensound_version}
Summary:        Open soundeffects for openRCT2
License:        CC-BY-SA-4.0
Group:          Amusements/Games/Strategy/Other
Requires:       openrct2 = %{openrct2_version}
BuildArch:      noarch

%description opensound
Open source sound effects for OpenRCT2

%prep
# Autosetup doesn't work here:
# https://github.com/rpm-software-management/rpm/issues/1204
%setup -q -n OpenRCT2-%{openrct2_version} -a 1 -a 2
%autopatch -p1

# Remove build time references so build-compare can do its work
sed -i "s/__DATE__/\"openSUSE\"/" src/openrct2/Version.h
sed -i "s/__TIME__/\"Build Service\"/" src/openrct2/Version.h

%build
export CXXFLAGS="%optflags -Wno-maybe-uninitialized"
%cmake -DDOWNLOAD_TITLE_SEQUENCES=OFF -DDOWNLOAD_OBJECTS=OFF
%make_build all
# libopenrct2 is not installed when openrct2 is called by make, so set the LD_LIBRARY_PATH
export LD_LIBRARY_PATH="$LD_LIBRARY_PATH:$(dirname $(find . -name libopenrct2.so))"
%make_build g2
# %%cmake changes directory into "build"
cd ..

# Generate titles from source (zipping as parkseq)
pushd title-sequences-%{title_version_url}/title
  mv -v v%{title_version} openrct2
  rm -rv v*
  for dir in *; do
    pushd "$dir"
    zip -9 -X -r ../"$dir"".parkseq" *
    popd
  done
popd

%install

install -dm755 %{buildroot}%{_datadir}/%{name}/

# Move preloaded openmusic and opensound in place so cmake will pick it up
cp %{_sourcedir}/openmusic-%{openmusic_version}.zip %{buildroot}%{_datadir}/%{name}/openmusic.zip
cp %{_sourcedir}/opensound-%{opensound_version}.zip %{buildroot}%{_datadir}/%{name}/opensound.zip

%cmake_install

mkdir -p '%{buildroot}%{_datadir}/%{name}/sequence'
cp -v title-sequences-%{title_version_url}/title/*.parkseq "%{buildroot}%{_datadir}/%{name}/sequence"

mkdir -p '%{buildroot}%{_datadir}/%{name}/object'
cp -vR objects-%{objects_version}/objects/* '%{buildroot}%{_datadir}/%{name}/object'

find '%{buildroot}%{_datadir}/%{name}' -type f -exec chmod 644 \{\} \;

cp %{SOURCE5} .

# We do that in the correct docdir in the files section.
rm -rf %{buildroot}%{_datadir}/doc

%fdupes %{buildroot}%{_datadir}/%{name}

%files
%license licence.txt
%doc distribution/changelog.txt distribution/readme.txt
%{_bindir}/openrct2
%{_bindir}/openrct2-cli
%{_libdir}/libopenrct2.so
%{_mandir}/man6/openrct2.6%{?ext_man}
%{_mandir}/man6/openrct2-cli.6%{?ext_man}
%{_datadir}/openrct2/
%exclude %{_datadir}/openrct2/sequence/rct*
%exclude %{_datadir}/%{name}/openmusic.zip.zipversion
%exclude %{_datadir}/%{name}/assetpack/openrct2.music.alternative.parkap
%exclude %{_datadir}/%{name}/opensound.zip.zipversion
%exclude %{_datadir}/%{name}/assetpack/openrct2.sound.parkap
%{_datadir}/icons/hicolor/*/apps/*
%{_datadir}/applications/*.desktop
%dir %{_datadir}/metainfo/
%{_datadir}/metainfo/openrct2.appdata.xml
%{_datadir}/mime/packages/openrct2.xml

%files titlesequences
%license title-sequences-%{title_version_url}/LICENSE
%{_datadir}/openrct2/sequence/rct*

%files openmusic
%license title-sequences-%{title_version_url}/LICENSE
%{_datadir}/%{name}/openmusic.zip.zipversion
%{_datadir}/%{name}/assetpack/openrct2.music.alternative.parkap

%files opensound
%license  COPYING
%{_datadir}/%{name}/opensound.zip.zipversion
%{_datadir}/%{name}/assetpack/openrct2.sound.parkap

%changelog
* Thu Aug 31 2023 Björn Bidar <bjorn.bidar@thaodan.de>
- Update to 0.4.5
  * Feature: gh#OpenRCT2/OpenRCT2#18713 Block brakes have speed control and brakes slower than adjacent block brakes copy block brake speed when block brake open.
  * Feature: gh#OpenRCT2/OpenRCT2#19276 Add Powered Lifthill to Giga Coaster.
  * Feature: gh#OpenRCT2/OpenRCT2#19305 Add new Reversed Trains ride setting to run trains backwards, granting a bonus to ride ratings.
  * Feature: gh#OpenRCT2/OpenRCT2#19305 [Plugin] Add “Car.isReversed” to allow individual ride vehicles to run backwards.
  * Feature: gh#OpenRCT2/OpenRCT2#19446 Add new color options to color dropdown.
  * Feature: gh#OpenRCT2/OpenRCT2#19547 Add large sloped turns to hybrid coaster and single rail coaster.
  * Feature: gh#OpenRCT2/OpenRCT2#19930 Add plugin APIs for research.
  * Feature: gh#OpenRCT2/OpenMusic#25 Added Prehistoric ride music style.
  * Feature: gh#OpenRCT2/OpenMusic#26 Fairground Organ style 2 with new recordings from Herman's 35er Voigt (Previously known as Bressingham Voigt).
  * Feature: gh#OpenRCT2/OpenMusic#28 Add Ragtime style 2 ride music.
  * Improved: gh#OpenRCT2/OpenRCT2#17739 Raise water and land height limits to 254 units/182m/600ft.
  * Improved: gh#OpenRCT2/OpenRCT2#18490 Reduce guests walking through trains on level crossing next to station.
  * Improved: gh#OpenRCT2/OpenRCT2#18996 When marketing campaigns are disabled, disable the Marketing tab in the Finances window.
  * Improved: gh#OpenRCT2/OpenRCT2#19764 Miscellaneous scenery tab now grouped next to the all-scenery tab.
  * Improved: gh#OpenRCT2/OpenRCT2#19830 “Highlight path issues” will now hide wall elements.
  * Improved: gh#OpenRCT2/OpenRCT2#19905 Add prompt before resetting shortcut keys.
  * Improved: gh#OpenRCT2/OpenRCT2#19952 Add colour preset to Spiral Slide using the new colour options.
  * Improved: gh#OpenRCT2/OpenRCT2#19953 Add keyboard shortcut to Keyboard Shortcuts window.
  * Improved: gh#OpenRCT2/OpenRCT2#20055 Performance improvement for the software renderer.
  * Change: gh#OpenRCT2/OpenSFX#17 Update Hybrid RC lifthill loop.
  * Fix: gh#OpenRCT2/OpenRCT2#12598 Number of holes is not set correctly when saving track designs.
  * Fix: gh#OpenRCT2/OpenRCT2#13130 Android always defaulting to UK locale for language, currency and temperature.
  * Fix: gh#OpenRCT2/OpenRCT2#13397 Ride simulation causes strange station behaviour and makes the ride unusable in some cases.
  * Fix: gh#OpenRCT2/OpenRCT2#16791 Rotodrop top piece replicates when walls are placed around it and clearance checks are disabled (original bug).
  * Fix: gh#OpenRCT2/OpenRCT2#18583 Land dropdown is incorrect if there are surface entry index holes.
  * Fix: gh#OpenRCT2/OpenRCT2#18895 Responding mechanic blocked at level crossing.
  * Fix: gh#OpenRCT2/OpenRCT2#19231 Crash due to null pointer to previously deleted banner in tile copy/paste functionality.
  * Fix: gh#OpenRCT2/OpenRCT2#19296 Crash due to a race condition for parallel object loading.
  * Fix: gh#OpenRCT2/OpenRCT2#19733 Favorite ride of X guests integer overflow.
  * Fix: gh#OpenRCT2/OpenRCT2#19756 Crash with title sequences containing no commands.
  * Fix: gh#OpenRCT2/OpenRCT2#19767 No message when path is not connected to ride exit and is therefore unreachable for mechanics.
  * Fix: gh#OpenRCT2/OpenRCT2#19800 Crash when displaying station stats with more than 62 stations.
  * Fix: gh#OpenRCT2/OpenRCT2#19801 The in-game load/save window cannot be resized anymore.
  * Fix: gh#OpenRCT2/OpenRCT2#19854 Looping Coaster trains clipping through steep quarter turns down.
  * Fix: gh#OpenRCT2/OpenRCT2#19858 Issue drawing simulate flag icon on alternate colour palettes.
  * Fix: gh#OpenRCT2/OpenRCT2#19901 Random shop colours never assigning last colour.
  * Fix: gh#OpenRCT2/OpenRCT2#19911 Guests stuck at certain railway crossings.
  * Fix: gh#OpenRCT2/OpenRCT2#19924 Destructible cheat does not allow partial ride modification.
  * Fix: gh#OpenRCT2/OpenRCT2#19950 Mine train block brake supports drawn incorrectly.
  * Fix: gh#OpenRCT2/OpenRCT2#19955 Mine Train Roller Coaster has incorrect supports on the sloped left small turn (original bug).
  * Fix: gh#OpenRCT2/OpenRCT2#19987 [Plugin] ‘SetCheatAction’ has wrong ID in plugin API.
  * Fix: gh#OpenRCT2/OpenRCT2#20016 The group box for small scenery details in the Tile Inspector window has unused empty space.
  * Fix: gh#OpenRCT2/OpenRCT2#20018 Shops not calculating up-keep cost.
  * Fix: gh#OpenRCT2/OpenRCT2#20033 Asset packs cannot reference game data.
  * Fix: gh#OpenRCT2/OpenRCT2#20104 [Plugin] Some network APIs use player index and group index.
  * Fix: gh#OpenRCT2/OpenRCT2#20099 Some scrollbar is glitched or have incorrect size when open window for the first time
  * Fix: gh#OpenRCT2/OpenRCT2#20134 Grass length being updated for tiles in the void, causing unneccesary drawing operations.
- Update dependencies
  * objects 1.3.11
  (sync with upstream CMakeLists.txt of 0.4.5)
- New dependencies
  * openmusic 1.3.0
  * opensound 1.0.3
- Drop in upstream included patches
  * 0001-GCC-13-fixes-19519.patch
  * 19283.patch
- Specificy the correct license of titlesequences
* Thu Aug 10 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Add 19283.patch: Fix build with new zip where zip_replace is
  deprecated.
* Sun Mar 19 2023 Björn Bidar <bjorn.bidar@thaodan.de>
- Fix loading of title sequences, adjust path.
  https://github.com/OpenRCT2/OpenRCT2/issues/8110
- Make titlesequences package noarch, it doesn't contain architecture specific
  files.
- Add 0001-GCC-13-fixes-19519.patch to fix building with GCC 13:
  https://github.com/OpenRCT2/OpenRCT2/pull/19519
- Update dependencies
  * objects 1.3.7 (sync with upstream CMakeLists.txt of 0.4.3)
* Thu Dec 15 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 0.4.3
  https://github.com/OpenRCT2/OpenRCT2/releases/tag/v0.4.3
* Wed Oct  5 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 0.4.2
  https://github.com/OpenRCT2/OpenRCT2/blob/develop/debian/changelog
- Update dependencies
  * title-sequences 0.4.0
  * objects 1.3.5
- Drop patch:
  * no-werror.patch
- Use "-Wno-maybe-uninitialized" to avoid compilation errors
* Sun Jun 26 2022 Berthold Gunreben <azouhr@opensuse.org>
- Program only knows little endian. Disable s390x builds.
* Mon Nov 22 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 0.3.5.1
  * Improved: The Tile Inspector window’s layout has been tweaked
    slightly.
  * Change: Weird bonus for path 0 - likely intended as a queue
    bonus (original bug).
  * Fix: Sometimes small scenery stays when building through it.
  * Fix: Placing track designs at locations blocked by anything
    results in wrong error message.
  * Fix: Tile Inspector can be resized too small.
  * Fix: Tile Inspector has inconsistent text colours.
  * Fix: Crash when opening a ride window for a corrupted vehicle.
  * Fix: Crash when track elements have no ride assigned.
  * Fix: Research status incorrectly considered for scenery when in
    editor modes.
  * Fix: Track designs of some ride types are incorrectly exported
    to TD6.
* Sun Aug  1 2021 Carsten Ziepke <kieltux@gmail.com>
- Update to version 0.3.4.1
  * Fix: Crash when placing large scenery.
  * Fix: Crash when removing litter with cheats.
  * Fix: Crash when using banner window.
  * Fix: Crash when opening large scenery signs.
  * Improved: Allow using RCT2 saves to mark RCT Classic
    (.sea) parks as finished and vice versa.
- Update to version 0.3.4
  * Feature: Track List window now displays the path
    to the design when debugging tools are on.
  * Feature: “Vandals stopped” statistic for security
    guards.
  * Feature: Lighting effects for shops and stalls.
  * Feature: Allow using early scenario completion
    in multiplayer.
  * Feature: [Plugin] Add property for getting current
    plugin api version.
  * Feature: [Plugin] Add properties related to guest
    generation.
  * Feature: [Plugin] Add properties related to climate
    and weather.
  * Feature: Opaque water (like in RCT1).
  * Change: [Plugin] Rename Object to LoadedObject to fix
    conflicts with Typescript's Object interface.
  * Change: [Plugin] Rename ListView to ListViewWidget to
    make it consistent with names of other widgets.
  * Change: “No construction above tree height” limitation
    now allows placing high trees.
  * Change: Redesign the About window, including new
    button to copy the current version info.
  * Fix: Visual glitches and crashes when using RCT1 assets
    from mismatched or corrupt CSG1.DAT and CSG1i.DAT files.
  * Fix: Windows can appear off screen with small
    screens or high scaling.
  * Fix: Opening the Options menu causes a noticeable
    drop in FPS.
  * Fix: Block brakes do not animate.
  * Fix: OpenGL: Track preview window, flip/rotate button
    do not update the thumbnail.
  * Fix: Crash when trying to rename Air Powered Vertical
    Coaster in Korean.
  * Fix: join_server uses default_port from config.
  * Fix: Entrances/exits are removed when built on top of
    each other.
  * Fix: Surface smoothing at extra zoom levels not
    working.
  * Fix: Cannot close Options window on Android.
  * Fix: [Plugin] isHidden only works for tile elements
    up to the first element with a base height of over 32.
  * Fix: Confusing message when joining server with
    mismatched network version.
  * Fix: American-style Steam Trains are not imported
    correctly from RCT1 saves.
  * Fix: The “About OpenRCT2” window cannot be themed.
  * Fix: Crash when painting Swinging Ships with
    invalid subtype.
  * Fix: Crash when window is closed during text input.
  * Fix: Ride/Track Design preview does not show if it
    costs more money than available.
  * Fix: Incorrect import of scenery research caused
    all scenery to be unlocked.
  * Fix: Incorrect function call in WallPlaceAction
    plugin code.
  * Fix: Crash when trying to place track when there
    are no free tile elements.
  * Fix: Unable to close changelog window when its
    content fails to load.
  * Fix: Incorrect drop height penalty on log flume ride.
  * Fix: Unable to build in multiplayer as client with
    "Build while paused" cheat enabled when the host is paused.
  * Improved: “Unlock operating limits” cheat now also
    unlocks all music.
  * Improved: Improve startup times.
  * Improved: Add Malgun Gothic and change Nanum Gothic
    filename for Korean.
- Update official objects to 1.2.1
  * Fix grass ID and source games
  * Split footpaths into footpaths and railings
* Fri Mar 19 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 0.3.3
  * An enhanced Track Designer with ability to add/remove
    scenery and footpaths.
  * The Track Designer has a pause button now.
  * There's a new single-rail roller coaster.
  * Terrain surfaces from RollerCoaster Tycoon 1 are now supported.
  * Lots of plugin improvements and new API additions.
  * Lots of bugfixes.
* Tue Dec 29 2020 Matthias Mailänder <matthias@mailaender.name>
- Update to version 0.3.2
- Note: this does now rely on the multi-header version of nlohmann-json
  (already included in Tumbleweed)
* Thu Oct  1 2020 Matthias Mailänder <mailaender@opensuse.org>
- Update to version 0.3.1 (enhancements of the plugin API)
* Fri Aug 28 2020 Matthias Mailänder <mailaender@opensuse.org>
- Update to version 0.3.0 (major feature: scripting support)
* Sat Jul  4 2020 Matthias Mailänder <mailaender@opensuse.org>
- Update to version 0.2.6 (see distribution/changelog.txt)
* Sun Mar 29 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 0.2.5. Many bugfixes since 0.2.3. Check
  https://github.com/OpenRCT2/OpenRCT2/releases for the full list
  New features:
  * Use a random title sequence each time it is shown.
  * Shortcut keys for the Tile Inspector.
  * Transport rides can now be synchronised.
  * Make Track Designs work in multiplayer.
  * Added window for scenery scatter tool
  * Console command to remove all floating objects.
  * Speed is automatically reset to normal upon scenario completion.
  * Remember current group in scenario list window.
  * Increase image list capacity by about 100k units.
  * Increase the number of ride music played
    simultaneously from 2 to 32.
- Drop fix-maybe-uninitialized.patch. Merged upstream.
* Mon Jul 15 2019 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 0.2.3:
  * Rides can now be simulated with ghost trains during construction.
  * Multi-threaded rendering.
  * Various other bugfixes and improvements.
- Added fix-maybe-uninitialized.patch to fix a gcc warning.
- Added no-werror.patch to build as wno-clobbered does not work
- Install needed object files
  * Fixed boo#1120400
- Splitted optional titlesequences as a subpackage (sequences
  which need RCT1 or RCT2 to be installed).
- Update to version 0.2.2:
  * Allow steep slopes on the side-friction roller coaster.
  * Mulitple glyphs for multiple eastern languages have been added
  * Allow building footpaths on 'corner down' terrain.
  * Allow building on-ride photos and water S-bends on the Water
    Coaster.
  * Add replay system.
  * No longer require the generic scenery groups and tarmac footpath
    to be checked when creating a scenario.
  * Client IP address is logged as `(null)` in server logs.
  * Fixed crash when switching between languages.
  * Fixed desync due to boats colliding with ghost pieces.
  * Removed support for scenario text objects.
  * Various other bugfixes and improvements
* Sun Sep  9 2018 mailaender@opensuse.org
- Update to version 0.2.1
- Drop mime.patch (included upstream)
- Drop appdata.patch (included upstream)
* Sat Aug 12 2017 mailaender@opensuse.org
- Add mime.patch
- Add appdata.patch
* Fri Aug 11 2017 mailaender@opensuse.org
- Update to version 0.1.1
- Drop libsuffix.patch
* Sat Jul 15 2017 mailaender@opensuse.org
- Update to version 0.1.0
- Drop download-title-sequences.patch (applied upstream)
- Don't require SDL2_ttf (not used anymore)
- Add libsuffix.patch
* Tue Feb  7 2017 mailaender@opensuse.org
- Update to version 0.0.6
  * Drop fix-no-real-prototypes.patch (included upstream)
- Fix the title sequences
  * Drop bundled-title-sequences.patch
  * Add download-title-sequences.patch
* Wed Jan 11 2017 rpm@fthiessen.de
- Update to version 0.0.5
  * First version which does not require original exe (just assets)
  * Runs on x64
- Added bundled-title-sequences.patch
- Removed upstream merged patches:
  * 3507.patch
  * 9d1fee2bda3dbbefbf69641876ba6315bcbe6da0.patch
* Sun May  8 2016 mailaender@opensuse.org
- Fix file-contains-date-and-time
* Fri May  6 2016 mailaender@opensuse.org
- update to version 0.0.4
* Wed Dec 30 2015 mailaender@opensuse.org
- initial packaging of version 0.0.3.1
